# h4-hello

[![PyPI - Version](https://img.shields.io/pypi/v/h4-hello.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/h4-hello.svg)
![Last Commit](https://img.shields.io/github/last-commit/heiwa4126/h4-hello)
![PyPI - License](https://img.shields.io/pypi/l/h4-hello.svg)](https://pypi.org/project/h4-hello)

**Table of Contents**

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)
- [Note](#note)

A practice project for publishing Python projects created with uv to PyPI with PEP740 signatures. Contains only a hello() function that returns "Hello!".

## Installation

```console
pip install h4-hello
```

## Usage

```console
$ h4-hello
Hello!
```

or

```python
from h4_hello.hello import hello
print(hello())
```

## License

`h4-hello` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Note

これがこのプロジェクトの本体。[NOTE-ja.md](NOTE-ja.md)\
( [GitHub レポジトリ](https://github.com/heiwa4126/h4-hello?tab=readme-ov-file#note) 上で見てください。PyPI 上だとリンク切れ)
